@@ -68,11 +68,11 @@ void device::register_sysfs_path(const char *path)
 {
 	char current_path[PATH_MAX + 1];
 	int iter = 0;
-	strcpy(current_path, path);
+	pt_strcpy(current_path, path);
 
 	while (iter++ < 10) {
 		char test_path[PATH_MAX + 1];
-		sprintf(test_path, "%s/device", current_path);
+		snprintf(test_path, sizeof(test_path), "%s/device", current_path);
 		if (access(test_path, R_OK) == 0)
 			strcpy(current_path, test_path);
 		else
@@ -166,11 +166,13 @@ void report_devices(void)
 
 
 
-	pw = global_joules_consumed();
+	pw = global_power();
 	if (pw > 0.0001) {
 		char buf[32];
 		wprintw(win, _("The battery reports a discharge rate of %sW\n"),
 				fmt_prefix(pw, buf));
+		wprintw(win, _("The power consumed was %sJ\n"),
+				fmt_prefix(global_joules(), buf));
 	}
 
 	if (show_power) {
@@ -248,13 +250,18 @@ void show_report_devices(void)
 	/* Device Summary */
 	int summary_size=2;
 	string *summary = new string[summary_size];
-	pw = global_joules_consumed();
+	pw = global_power();
 	char buf[32];
 	if (pw > 0.0001) {
 		summary[0]= __("The battery reports a discharge rate of: ");
 		summary[1]=string(fmt_prefix(pw, buf));
 		summary[1].append(" W");
 		report.add_summary_list(summary, summary_size);
+
+		summary[0]= __("The power consumed was : ");
+		summary[1]=string(fmt_prefix(global_joules(), buf));
+		summary[1].append(" J");
+		report.add_summary_list(summary, summary_size);
 	}
 
 	if (show_power) {
