@@ -40,6 +40,8 @@ class usbdevice: public device {
 	int index;
 	int r_index;
 	int rootport;
+	int busnum;
+	int devnum;
 public:
 
 	usbdevice(const char *_name, const char *path, const char *devid);
@@ -53,6 +55,7 @@ public:
 
 	virtual const char * device_name(void);
 	virtual const char * human_name(void);
+	virtual void register_power_with_devlist(struct result_bundle *results, struct parameter_bundle *bundle);
 	virtual double power_usage(struct result_bundle *result, struct parameter_bundle *bundle);
 	virtual int power_valid(void) { return utilization_power_valid(r_index);};
 	virtual int grouping_prio(void) { return 4; };
